psychopy_ext.exp.MouseRespGroup — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.MouseRespGroup

class `psychopy_ext.exp.` `MouseRespGroup`(win, stimuli, respmap=None, multisel=False, on_color='#ff7260', off_color='white', pos=(0, 0), name='')
  `__init__`(win, stimuli, respmap=None, multisel=False, on_color='#ff7260', off_color='white', pos=(0, 0), name='')

  Methods

  `__init__`(win, stimuli[, respmap, multisel, ...]) |
  `contains`(*args, **kwargs) |
  `draw`() |
  `reset`() |
  `select`([stim]) |
  `setPos`(newPos) |